@@ -7,6 +7,13 @@ service:
   config:
     user_name: you
 
+# Webapi Service
+#service:
+#  name: msgflow.service.WebapiService
+#  config:
+#    host: 0.0.0.0
+#    port: 8080
+
 # Twitter service
 #service:
 #  name: msgflow.service.TwitterSampleStreamService
@@ -46,17 +53,13 @@ app:
 """
 
 
-INIT_APP = (
-    """
+INIT_APP = """
 class MyApp:
-    def __init__(self, service, config):
-        """
-    """
-        self._service = service
+    def __init__(self, config):
+        pass
 
-    def handle(self, message):
-        res = f'{message.text}'
-        message.respond(res)
-        self._service.post(f'Log: "{message.text}"')
+    def handle(self, bot, msg):
+        log_msg = f'App got message: Message(text="{msg.text}", conversation_id="{msg.conversation_id}")'
+        bot.post(log_msg)
+        msg.respond(f'Thank you for your message "{msg.text}"!')
 """
-)
